summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtexturebaseedit.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kpovmodeler/pmtexturebaseedit.h
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pmtexturebaseedit.h')
-rw-r--r--kpovmodeler/pmtexturebaseedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmtexturebaseedit.h b/kpovmodeler/pmtexturebaseedit.h
index 8e89af9f..8178b612 100644
--- a/kpovmodeler/pmtexturebaseedit.h
+++ b/kpovmodeler/pmtexturebaseedit.h
@@ -35,12 +35,13 @@ class PMLinkEdit;
class PMTextureBaseEdit : public PMNamedObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMTextureBaseEdit with parent and name
*/
- PMTextureBaseEdit( TQWidget* parent, const char* name = 0 );
+ PMTextureBaseEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class PMLinkEdit;
public:
/**
- * Creates a PMTextureBaseEdit with parent and name
+ * Creates a PMTextureBaseEdit with tqparent and name
*/